is_valid_identifier

Function is_valid_identifier 

pub fn is_valid_identifier(s: &str) -> bool
Check if a string is a valid unquoted identifier.

PostgreSQL unquoted identifiers must start with a letter or underscore, and can contain letters, digits, underscores, and dollar signs.